@@ -19,11 +19,15 @@
  *
  */
 
+#include "config.h"
+
 #include <string.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
+#include <glib/gi18n.h>
+
 #include "gs-theme-window.h"
 #include "gs-theme-engine.h"
 #include "gste-popsquares.h"
@@ -35,17 +39,18 @@ main (int argc, char **argv)
         GtkWidget     *window;
         GError        *error;
 
-#ifdef ENABLE_NLS
         bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-# ifdef HAVE_BIND_TEXTDOMAIN_CODESET
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-# endif
         textdomain (GETTEXT_PACKAGE);
-#endif
 
         error = NULL;
 
-        gtk_init_with_args (&argc, &argv, NULL, NULL, NULL, &error);
+        if (!gtk_init_with_args (&argc, &argv, NULL, NULL, NULL, &error)) {
+		g_printerr ("%s. See --help for usage information.\n",
+			    error->message);
+		g_error_free (error);
+	        exit (1);
+	}
 
         window = gs_theme_window_new ();
         g_signal_connect (G_OBJECT (window), "delete-event",
